package proxy.network;

import proxy.Proxy;
import proxy.packet.handshake.client.C00Handshake;
import proxy.packet.login.server.S00PacketDisconnect;

public class NetHandlerHandshake implements INetHandler {
	private final Proxy proxy;
	private final NetworkManager connection;

	public NetHandlerHandshake(Proxy proxy, NetworkManager connection) {
		this.proxy = proxy;
		this.connection = connection;
	}

	public void processHandshake(C00Handshake packet) {
		switch(packet.getRequestedState()) {
			case LOGIN:
				this.connection.setConnectionState(EnumConnectionState.LOGIN);
	
				if(packet.getProtocolVersion() > 47) {
					String text = "Outdated server! I\'m still on 1.8.9";
					this.connection.sendPacket(new S00PacketDisconnect(text));
					this.connection.closeChannel(text);
				}
				else if(packet.getProtocolVersion() < 47) {
					String text = "Outdated client! Please use 1.8.9";
					this.connection.sendPacket(new S00PacketDisconnect(text));
					this.connection.closeChannel(text);
				}
				else {
					this.connection.setNetHandler(new NetHandlerLoginServer(this.proxy, this.connection));
				}
	
				break;
	
			case STATUS:
				this.connection.setConnectionState(EnumConnectionState.STATUS);
				this.connection.setNetHandler(new NetHandlerStatusServer(this.proxy, this.connection));
				break;
	
			default:
				throw new UnsupportedOperationException("Invalid intention " + packet.getRequestedState());
		}
	}

	public void onDisconnect(NetworkManager connection, String reason) {
	}
}
